;hi-res
;$2000-$3fff page1
;$4000-$5fff page2

;       $2000       |     $2001       |     $2002
;B: 0 1 2 3 4 5 6 7 | 0 1 2 3 4 5 6 7 | 0 1 2 3 4 5 6 7 
;C: v g v g v g v g | g v g v g v g 0 | g v g v g v g 0 
;   b 0 b 0 b 0 b 1 | 0 b 0 b 0 b 0 1 | 0 b 0 b 0 b 0 1 
;X  0 1 2 3 4 5 6 - | 7 8 9 0 1 2 3 - | 4 5 6 7 8 9 0 - 

; even numbered colors plot only even coordinates, odd numbered colors plot only odd coordinates
; green being an odd-value color is not plotted at X=0
; Not every color canbe displayed at every X coordinate. even colors(2=violet,blue=4) available only on even coordinates
; Odd colors(green=1,orange=5) are available only at odd X coordinates

;2. Within any byte, bit 7 is used to determine which row – top  o r botto m – is - selected.
; This means that for  any  particular  group  of seven  dot positions, represented
;  by a single byte, only the colors in either the  top  or bottom  rows can be shown
;  at one time. For example, it is not possible to have green and orange  dots
; displayed simultaneously within the same seven-dot group.
;3. The order of the colors within every other byte is reversed with  respect to its
; neighbors. This is to ensure that the individual colors properly alternate with
; successive X position, such as between bytes 0 and  1, 1  and 2 , and  so  on .

; Set 1     Set 1
;00=Black  100=Black2
;01=Green  101=Orange
;10=Violet 110=Blue
;11=White1 111=White2

;Now perhaps it will make a little more sense. Set 1 colors are all those selected  when
;the high-order bit is of (bit 7  =  0). Set 2 are all those selected when the high-order
;bit is on (bit 7 = 1). Any attempt to plot a point from one set will convert any existing
;dots from the other set, provided all dots are deined within a common byte.
;Obviously,plotting a dot at X coordinate 7 (byte $2001) will not have any efect on dot
;positions 0 to 6 ,since they are stored in a separate byte ($2000).

;Within a particular byte, bit 7 will always be left in a state determined by the
;nature of the last color plot, regardless of how many dots were previously in
;some other particular condition. This is why  the  earlier diagonal line plot acted
;so strangely. By clearing the screen to green, every screen byte was set so as to
;have the green bits on and the violet bits of (bit 7 = 0). See Figure 20-2.

;Figure 20-2: Bit Values for Green Pixels 
;
;Location $2000, for example, would hold the value $2A. Since the pattern is 
;shifted for $2001, an all-green dot group would correspond to the value $55. To 
;add to the confusion, remember that Figure 20-1 shows the bits in the reverse 
;order from the notation normally used in this book. Ordinarily we’d show loca- 
;tion $2000 holding a $2A in binary notation as: 00101010. Since the screen dots 
;are displayed by least-significant position first, though, this is reversed when 
;showing a screen display to make it easier to interpret: 
;
;$2A = 00101010 -A (reverse to match Figure 20-1) -A 01010100 
;and for the other bytes: 
;
;$5A = 01010101 -A (reversed) -> 10101010 
;
;When HPLOT tried to draw an orange dot at 0, 0 we would ordinarily 
;expect no effect. However, the high bit was reversed, and this converted the dis - 
;play of all current green dots to orange. 
;
;At all odd coordinates the direct plot is successful, but all remaining dots in 
;the particular byte still converted to their high-bit-on equivalents. 
;
;Figure 20-3 shows the contents of $2000 to $2002 after the orange HPLOT. 


 *=$4000
 !to "PSG.bin", plain	; set output file and format
 !cpu 6502		; set processor type

HPAG	=	$E6	;Page where plotting will be done: ;page 1 = $20, page 2 = $40
;SETHIRES	= $C057 ;select Hi-res
;PAGE1		= $C054 ;select text/graphics page1
;
;CLRTEXT		= $C050 ;display graphics
;SETTEXT		= $C051 ;display text
;CLRMIXED	= $C052 ;clear mixed mode- enable full graphics
;SETMIXED	= $C053 ;enable graphics/text mixed mode

; precalc adresses
GBASL=$26
GBASH=$27
HPAG2=$E6;     Applesoft puts it here anyway.

TLO=$1000
;+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
OUT1		= $20 ; +$21
OUT2		= $22 ; +$23


; CONSTANTES PROGRAMME =================
Reg00		= $F0;1000
Reg01		= Reg00 + $1;00
Reg02		= Reg01 + $1;00
Reg03		= Reg02 + $1;00
Reg04		= Reg03 + $1;00
Reg05		= Reg04 + $1;00
Reg06		= Reg05 + $1;00
Reg07		= Reg06 + $1;00
Reg08		= Reg07 + $1;00
Reg09		= Reg08 + $1;00
Reg10		= Reg09 + $1;00
Reg11		= Reg10 + $1;00
Reg12		= Reg11 + $1;00
Reg13		= Reg12 + $1;00
;+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
;zero memory
	lda #20
	sta $1B
	ldy #0
	sty $1A
zlp1
	lda #0
zlp2
	sta ($1A),y
	iny
	bne zlp2
	inc $1B
	lda $1B
	cmp #$40
	bne zlp1

;setup hires
;                  POKE(0xc057,0);   /* hi res */
	sta $c057
;                  POKE(0xc055,0);   /* page 2 */
;	sta $c055
;                  POKE(0xc050,0);   /* set graphics */
	sta $c050
;                  POKE(0xc052,0);   /* full graphics */
	sta $c052


;precalc base lines;;;;;;;;;;;;;;;;;;;
zeroa=TLO+1024
	lda #$10;HPAG2 = $10 for base $2000, $20 for base $4000
	sta HPAG2
	ldy #0
clp
	tya
	jsr CALC
	lda GBASL
	clc
	adc #6
	sta TLO,Y

	lda GBASH
	sta TLO+256,Y

	lda #0
	sta zeroa,y
	lda #$40
	sta zeroa+256,y

; precalc /7//////////////
	tya
	sta 6

	ldy #0
;	TXA ;X
	CPY	#0
	BEQ	locF442
locF441:
		INY
locF442
		SBC	#7
		BCS	locF441
;		STY	$E5
;		tax

	tax
	LDA	unk_F4B9,X

		ldx 6
		sta TLO+512,X ;%7
		tya
		sta TLO+768,X;/7
	ldy 6
;////////////////////////
	iny
	bne clp
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	lda #0
	sta 6
	sta $1C
;	jsr $F3E2;hgr page 1
	ldx #3
;	jsr LF6F0;HCOLOR, x=0-7
	LDA	unk_F6F6,X
	STA	$E4		; HGR.COLOR

;/////////////////////////////////////////////////
	lda #tunep&255
	sta src
	lda #tunep/256
	sta src+1

	lda #tune&255
	sta dst
	lda #tune/256
	sta dst+1

	jsr unpmain
	lda #$FD
	sta tune+11610
	sta tune+11610+1

		LDA #00
		STA OUT2
.bdet	LDA #$04				; on commence en $C7 jusqu'en $C1
		ORA #$C0				; -> $Cx
		STA OUT2+1

;Temp		= $FF
;		; MB / SLOT #?
;		LDA #00
;		STA OUT2
;.bdet	LDA #$07				; on commence en $C7 jusqu'en $C1
;		ORA #$C0				; -> $Cx
;		STA OUT2+1
;		LDY #04					; $CX04
;		LDX #02					; 2 vйrifs
;
;.bt		LDA (OUT2),Y			; timer 6522 (Low Order Counter) - attention compte а rebour !
;		STA Temp				; 3 cycles
;		LDA (OUT2),Y			; + 5 cycles = 8 cycles entre les deux accиs au timer
;		SEC						; 
;		SBC Temp				; 
;		CMP #$F8				; -8 (compte а rebour) ?
;		BNE .Ko
;		DEX
;		BNE .bt					; boucle dйtection
;		INX						; Mocking OK (X=1)
;	
;;		; GOOD GUY final !	
;		LDA $C083				;
;		LDA $C083				; RAM utilisable entre $D000/$FFFF (bank2)
;;		JMP DEBUT2				; retour dans main
;		jmp exi
;		; bad guy slot #
;.Ko		DEC .bdet+1				; on dйcrйmente le "slot"
;		BNE	.bdet				; on boucle de 7 а 1
;by jmp by
;exi
; =============================================================================
; init Mockingboard		 		
	
		; PREMIER init MB (OUT1/OUT2)
		LDA   	#$FF
		LDY	  	#$03
		STA 	(OUT2),Y	; STA   $C403		; DDRA1
		LDY 	#$83
		STA 	(OUT2),Y	; STA   $C483		; DDRA2
		LDA   	#$07
		LDY 	#$02
		STA		(OUT2),Y	; STA   $C402		; DDRB1
		LDY 	#$82
		STA		(OUT2),Y	; STA   $C482		; DDRB2

		LDA 	OUT2+1
		STA		OUT1+1		;
		STA		OFFBIT+2	; fixe BIT $Cx04 (rйinit interruption) du player
		LDA 	#01
		STA 	OUT1

; ==============================================================================

; 81  REM  CALL INIT FOR BOTH 6522
; 82  CALL 36864: CALL 36908:REM $9000,$902C
	JSR L9000
	JSR L902C
;; 84  REM  CALL RESET FOR BOTH 6522
;; 85  CALL 36897: CALL 36941:REM $9021,$904D
	JSR L9021
	JSR L904D

	sei			; disable interrupts just in case

	lda	#$40		; Continuous interrupts, don't touch PB7
	sta	$C40B		; ACR register
	lda	#$7F		; clear all interrupt flags
	sta	$C40E		; IER register (interrupt enable)

	lda	#$C0
	sta	$C40D		; IFR: 1100, enable interrupt on timer one oflow
	sta	$C40E		; IER: 1100, enable timer one interrupt

	lda	#$E7
	sta	$C404		; write into low-order latch
	lda	#$4f
	sta	$C405		; write into high-order latch,
				; load both values into counter
				; clear interrupt and start counting

		LDA #<PLAYER_PSG
		STA $03FE
		LDA #>PLAYER_PSG
		STA $03FF

	cli
;/////////////////////////////////////////////////
;;;;;;;;;;;;;start

;C054 49236 TXTPAGE1     OECG WR   Display Page 1
;C055 49237 TXTPAGE2     OECG WR   If 80STORE Off: Display Page 2
sdlp
	jsr VBLANK
	lda $C054
	jsr sdp
	jmp sdlp

;	inc sdp+1
;sdp
;	lda #$FF
;	and #1
;	tay
;	lda $C054,Y

;	lda sdx+1
;	eor #$60
;	sta sdx+1

sdp
	inc sdv2+1
	inc sdv2+1
sdv2
	lda #0
	sta 7

mu

;Box(64+t1(a),64+t1(i),1,1,RGB(0,255,0))
sdy
	ldy #0
	ldx sind,y
;	ldy 6;Y
	lda TLO,X
	sta GBASL
	lda TLO+256,X
;sdx	eor #$00
	sta GBASH

	lda zeroa,y
	sta 8
	lda zeroa+256,y
	sta 9
	lda #0
	tay
	sta (8),y

		ldx 7
		lda sind,x
		;and #$FE
		ora #1
		tay
		inc 7

		lda TLO+512,Y ; %7
		STA	$30		; COLOR
		lda TLO+768,Y ; /7
		tay

;		LDA	unk_F4B9,X
;		STA	$30		; COLOR
;;		TYA
		LSR	;/2
		LDA	$E4		; HGR.COLOR
		STA	$1C		; HGR.BITS
		BCS	loc_F47E
		bcc locret_F489;jmp locret_F489
loc_F47E:
		ASL	
		CMP	#$C0
		BPL	locret_F489
		LDA	$1C
		EOR	#$7F
		STA	$1C
locret_F489:

		LDA	$1C		; HGR.BITS
		EOR	($26),Y		; GBASL
		AND	$30		; COLOR
		EOR	($26),Y
		STA	($26),Y


	ldx sdy+1

	tya
	clc
	adc $26
	bcc noinc27
	inc $27
noinc27
	sta zeroa,X
	lda $27
	sta zeroa+256,X

	inx
	stx sdy+1
	bne mu

	rts
;	lda sdx+1
;	eor #$60
;	sta sdx+1

;	jmp sdlp

sind
!binary "sindots.bin"
unk_F4B9:
!binary "F4B9.bin"
;*********************************************************************************
;HPOSN $F411 Positions hi-res “cursor” without plotting. Enter with  X, Y (low, high) = horizontal position, Accumulator =  vertical position.
;sub_F411:
;		STA	$E2 ;Y
;		STX	$E0		; HGR.X
;		STY	$E1		; HGR.X+1
;		PHA
;		AND	#$C0
;		STA	$26
;		LSR	
;		LSR	
;		ORA	$26
;		STA	$26 ; GBASL
;		PLA
;		STA	$27
;		ASL	
;		ASL	
;		ASL	
;		ROL	$27
;		ASL	
;		ROL	$27
;		ASL	
;		ROR	$26
;		LDA	$27
;		AND	#$1F
;		ORA	$E6		; HGR.PAGE
;		STA	$27		; GBASH
;
;entry2:
;		TXA ;X
;
;;div 7, if y<>0
;		CPY	#0
;		BEQ	loc_F442
;		LDY	#$23 ; 245
;		ADC	#4
;loc_F441:
;		INY
;loc_F442:
;		SBC	#7
;		BCS	loc_F441
;
;		STY	$E5		; HGR.HORIZ
;		TAX
;entry3:
;		LDA	unk_F4B9,X
;		STA	$30		; COLOR
;		TYA
;		LSR	;/2
;		LDA	$E4		; HGR.COLOR
;		STA	$1C		; HGR.BITS
;		BCS	loc_F47E
;		RTS
;;---------------------------------------------------------------------------
;loc_F47E:
;		ASL	
;		CMP	#$C0
;		BPL	locret_F489
;		LDA	$1C
;		EOR	#$7F
;		STA	$1C
;		RTS
;locret_F489:
;		RTS
;---------------------------------------------------------------------------
;unk_F4B9:
;!binary "F4B9.bin"

;HPLOT0:				; hposn
;		JSR	entry3;sub_F411
;		LDA	$1C		; HGR.BITS
;		EOR	($26),Y		; GBASL
;		AND	$30		; COLOR
;		EOR	($26),Y
;		STA	($26),Y
;		RTS

;HCOLOR $F6F0 Sets HCOLOR to contents of X - Register (0 −7).
;LF6F0:
;		LDA	unk_F6F6,X
;		STA	$E4		; HGR.COLOR
;		RTS
; ---------------------------------------------------------------------------
unk_F6F6:
		!byte	0
		!byte $2A
		!byte $55
		!byte $7F
		!byte $80
		!byte $AA
		!byte $D5
		!byte $FF
		!byte $C9

LF3E2
		LDA	#$20 ; ' '      ; HGR,f3e2
		BIT	$C054
		BIT	$C053

		STA	$E6
		LDA	$C057
		LDA	$C050

Lf3f2:					; hclr
		LDA	#0
		STA	$1C

Lf3f6:					; bkgnd
		LDA	$E6
		STA	$1B
		LDY	#0
		STY	$1A

loc_F3FE:
		LDA	$1C
		STA	($1A),Y
		JSR	loc_F47E
		INY
		BNE	loc_F3FE
		INC	$1B
		LDA	$1B
		AND	#$1F
		BNE	loc_F3FE
		RTS
;*********************************************************************************
;-------------------------------
; Wait for vertical blank (IIe/IIGS)
;-------------------------------
VBLANK
loop1 lda $c019
	bpl loop1
loop lda $c019
	bmi loop ;wait for beginning of VBL interval
	rts

CALC   ASL          ;A--BCDEFGH0
       TAX          ;TAX...TXA could be TAY...TYA
       AND #$F0     ;A--BCDE0000
       BPL .1       ;B=0
       ORA #$05     ;A--BCDE0B0B
.1     BCC .2       ;A-0
       ORA #$0A     ;A--BCDEABAB
.2     ASL          ;B--CDEABAB0
       ASL          ;C--DEABAB00
       STA GBASL
       TXA          ;C--BCDEFGH0
       AND #$0E     ;C--0000FGH0
       ADC HPAG2    ;O--OOxxFGH0
;HPAG2 = $10 for base $2000, $20 for base $4000
       ASL GBASL    ;D--00xxFGHC  GBASL=EABAB000
       ROL          ;0--0xxFGHCD
       STA GBASH
       RTS

PLAYER_PSG

		; save
		PHP					; on sauve les flags
		PHA					; on sauve A
		TXA					; on sauve 
		PHA					; X
		TYA					; on sauve
		PHA					; Y
		
;		inc $400

	jsr psgp

		LDA OUT1			; permutation g/d
		EOR #$80			
		STA OUT1			
		LDA OUT2			
		EOR #$80			
		STA OUT2			

		LDY #00				; 
		LDX #0;IndexPlayFrame

		; REGISTRE 0
		LDA #00				; registre 0
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg00,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)
		
		; REGISTRE 1
		LDA #01				; registre 1
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg01,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 2
		LDA #02				; registre 2
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg02,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 3
		LDA #03				; registre 3
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg03,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 4
		LDA #04				; registre 4
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg04,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 5
		LDA #05				; registre 5
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg05,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 6
		LDA #06				; registre 6
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg06,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 7
		LDA #07				; registre 7
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg07,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 8
		LDA #08				; registre 8
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg08,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 9
		LDA #09				; registre 9
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg09,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 10
		LDA #10				; registre 10
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg10,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 11
		LDA #11				; registre 11
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg11,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 12
		LDA #12				; registre 12
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		LDA Reg12,X			; 
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		; REGISTRE 13		; spйcification YM format / shunte si = $FF
		LDA Reg13,X			; 
		CMP #$FF
		BEQ .shunte13
		TAX
		
		LDA #13				; registre 13
		STA (OUT1),Y		; ORA1 (data)
		LDA #$07			; Set fct "Set PSG Reg #"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)

		TXA
		STA (OUT1),Y		; ORA1 (data)
		LDA #$06			; Set fct "Write DATA"
		STA (OUT2),Y		; ORB1 (fct)
		LDA #$04			; Set fct "Inactive"
		STA (OUT2),Y		; ORB1 (fct)
.shunte13

;	jmp ply
OFFBIT	BIT $C404           ; Clears interrupt (T1CL) pour pouvoir кtre de nouveau rйutilisй! 

		PLA
		TAY					; on rйcup Y
		PLA
		TAX					; on rйcup X
		PLA					; on rйcup A
		PLP
		RTI					; sortie 1
;-----------------------------------
psgp
 LDA #01
 cmp #0
 BEQ PSGA
 DEC psgp+1
 RTS
PSGA
;psgplay:ld a,1:or a:jr z,psga
; dec a:ld (psgplay+1),a:ret
;psga: ld hl,song+16
;
dumpreg
	JSR GETB
	CMP #$FF
	BNE CONT
	RTS
CONT
	CMP #$FE
	BNE nogetwait
	JSR GETB
	ASL
	ASL
	STA psgp+1
	RTS
;dumpreg:
; 	ld e,(hl):inc hl
; 	ld a,e
; 	cp #FF:jr z,stoplay
; 	cp #FE:jr nz,nogetwait
;    ld e,(hl):inc hl;(hl)*4
; ld a,e
; add a,a
; add a,a
; ld (psgplay+1),a:jr stoplay

nogetwait
	CMP #$FD
	BEQ CONT2

;port#,data
;	cmp #7
;	bne cont3
;	JMP GETB
;
cont3
;	STA $C401
;	JSR L900B
	tay

	JSR GETB
	STA Reg00,y;$C401
;	JSR L9016
	JMP dumpreg
CONT2
	LDA #<tune+16
	STA GETB+1
	LDA #>tune+16
	STA GETB+2
	RTS
;nogetwait:
;    cp #FD:jr z,stoplay2
;	ld bc,0xfffd
;	out (c),e
;	ld e,(hl):inc hl
;
;  
;	ld b,0xbf
;	out (c),e
;    jr dumpreg
;stoplay2:
;  ld hl,song+16
;stoplay:
; ld (psga+1),hl
; ret
;-----------------------------------
GETB
 LDA tune+16
 INC GETB+1
 BNE no_tune_inc
 INC GETB+2
no_tune_inc
 RTS
;-----------------------------------


;waitvb
;	pha
;;$C019  Bit 7 of this location will be a 0 when the 
;;video beam is in the vertical retrace region.
;rdvbl
;        bit $c019
;        bmi rdvbl
;        lda $c070
;loop
;        bit $c019 
;        bpl loop
;        pla
;		rts
;OFFBIT	BIT $C404           ; Clears interrupt (T1CL) pour pouvoir кtre de nouveau rйutilisй! 

;-------------------------------------------------------------------------------------------
L9000 ;INIT
	LDA   #$FF
	STA   $C403
	LDA   #$07
	STA   $C402
	RTS

L900B ;LATCH
	LDA   #$07
	STA   $C400
	LDA   #$04
	STA   $C400
	RTS

L9016 ;WRITE
	LDA   #$06
	STA   $C400
	LDA   #$04
	STA   $C400
	RTS

L9021 ; RESET
	LDA   #$00
	STA   $C400
	LDA   #$04
	STA   $C400
	RTS

L902C ;INIT2
	LDA   #$FF
	STA   $C483
	LDA   #$07
	STA   $C482
	RTS

L9037 ; LATCH2
	LDA   #$07
	STA   $C480
	LDA   #$04
	STA   $C480
	RTS

L9042 ; WRITE2
	LDA   #$06
	STA   $C480
	LDA   #$04
	STA   $C480
	RTS

L904D ; RESET2
	LDA   #$00
	STA   $C480
	LDA   #$04
	STA   $C480
	RTS

;TLO
unpmain
!src "zx7.s"
tunep
!binary "atf.psg.zx7"
tune
